<div align="center">
  <!-- <img src="https://pandas.pydata.org/static/img/pandas.svg"><br> -->
</div>

-----------------

# panndas: neural networks in pandas
[![PyPI Latest Release](https://img.shields.io/pypi/v/panndas.svg)](https://pypi.org/project/panndas/)
[![Package Status](https://img.shields.io/pypi/status/panndas.svg)](https://pypi.org/project/panndas/)
[![License](https://img.shields.io/pypi/l/panndas.svg)](https://github.com/pandas-dev/pandas/blob/main/LICENSE)
[![Coverage](https://codecov.io/github/charlesfrye/panndas/coverage.svg?branch=main)](https://codecov.io/gh/charlesfrye/panndas)
[![Downloads](https://static.pepy.tech/personalized-badge/panndas?period=month&units=international_system&left_color=black&right_color=orange&left_text=PyPI%20downloads%20per%20month)](https://pepy.tech/project/panndas)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)

## What is it?

**pandas** is a Python package that provides fast, flexible, and expressive data
structures designed to make working with "relational" or "labeled" data both
easy and intuitive.

**panndas** is a neural network library built on top of pandas as a joke.

## Main Features
Here are just a few of the things that panndas does well:

  -

## License
[YOLO](LICENSE)

## Contributing to panndas [![Open Source Helpers](https://www.codetriage.com/pandas-dev/pandas/badges/users.svg)](https://www.codetriage.com/pandas-dev/pandas)

All contributions, bug reports, bug fixes, documentation improvements, enhancements, and ideas are unwelcome.
